@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 require 'set'
 
 module Listen
   # TODO: refactor (turn it into a normal object, cache the stat, etc)
   class Directory
+    # rubocop:disable Metrics/MethodLength
     def self.scan(snapshot, rel_path, options)
       record = snapshot.record
       dir = Pathname.new(record.root)
@@ -14,7 +17,7 @@ module Listen
       path = dir + rel_path
       current = Set.new(_children(path))
 
-      Listen::Logger.debug do
+      Listen.logger.debug do
         format('%s: %s(%s): %s -> %s',
                (options[:silence] ? 'Recording' : 'Scanning'),
                rel_path, options.inspect, previous.inspect, current.inspect)
@@ -36,22 +39,19 @@ module Listen
       previous = previous.reject { |entry, _| current.include? path + entry }
 
       _async_changes(snapshot, Pathname.new(rel_path), previous, options)
-
     rescue Errno::ENOENT, Errno::EHOSTDOWN
       record.unset_path(rel_path)
       _async_changes(snapshot, Pathname.new(rel_path), previous, options)
-
     rescue Errno::ENOTDIR
       # TODO: path not tested
       record.unset_path(rel_path)
       _async_changes(snapshot, path, previous, options)
       _change(snapshot, :file, rel_path, options)
     rescue
-      Listen::Logger.warn do
-        format('scan DIED: %s:%s', $ERROR_INFO, $ERROR_POSITION * "\n")
-      end
+      Listen.logger.warn { format('scan DIED: %s:%s', $ERROR_INFO, $ERROR_POSITION * "\n") }
       raise
     end
+    # rubocop:enable Metrics/MethodLength
 
     def self.ascendant_of?(base, other)
       other.ascend do |ascendant|
@@ -86,8 +86,8 @@ module Listen
       # https://github.com/jruby/jruby/issues/3840
       exists = path.exist?
       directory = path.directory?
-      return path.children unless exists && !directory
-      raise Errno::ENOTDIR, path.to_s
+      exists && !directory and raise Errno::ENOTDIR, path.to_s
+      path.children
     end
   end
 end
