@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Listen
   class Silencer
     # The default list of directories that get ignored.
@@ -12,7 +14,7 @@ module Listen
       | log
       | tmp
       |vendor/ruby
-    )(/|$)}x
+    )(/|$)}x.freeze
 
     # The default list of files that get ignored.
     DEFAULT_IGNORED_EXTENSIONS = %r{(?:
@@ -53,36 +55,36 @@ module Listen
       | \.DS_Store
       | \.tmp
       | ~
-    )$}x
+    )$}x.freeze
 
+    # TODO: deprecate these mutators; use attr_reader instead
     attr_accessor :only_patterns, :ignore_patterns
 
-    def initialize
-      configure({})
+    def initialize(**options)
+      configure(options)
     end
 
+    # TODO: deprecate this mutator
     def configure(options)
       @only_patterns = options[:only] ? Array(options[:only]) : nil
       @ignore_patterns = _init_ignores(options[:ignore], options[:ignore!])
     end
 
-    # Note: relative_path is temporarily expected to be a relative Pathname to
-    # make refactoring easier (ideally, it would take a string)
-
-    # TODO: switch type and path places - and verify
     def silenced?(relative_path, type)
-      path = relative_path.to_s
+      path = relative_path.to_s   # in case it is a Pathname
 
-      if only_patterns && type == :file
-        return true unless only_patterns.any? { |pattern| path =~ pattern }
-      end
-
-      ignore_patterns.any? { |pattern| path =~ pattern }
+      _ignore?(path) || (only_patterns && type == :file && !_only?(path))
     end
 
     private
 
-    attr_reader :options
+    def _ignore?(path)
+      ignore_patterns.any? { |pattern| path =~ pattern }
+    end
+
+    def _only?(path)
+      only_patterns.any? { |pattern| path =~ pattern }
+    end
 
     def _init_ignores(ignores, overrides)
       patterns = []
