@@ -1,5 +1,6 @@
-RSpec.describe Listen::Adapter::Base do
+# frozen_string_literal: true
 
+RSpec.describe Listen::Adapter::Base do
   class FakeAdapter < described_class
     def initialize(config)
       @my_callbacks = {}
@@ -24,6 +25,7 @@ RSpec.describe Listen::Adapter::Base do
     end
   end
 
+  let(:thread) { instance_double(Thread, "thread") }
   let(:dir1) { instance_double(Pathname, 'dir1', to_s: '/foo/dir1') }
 
   let(:config) { instance_double(Listen::Adapter::Config) }
@@ -42,11 +44,14 @@ RSpec.describe Listen::Adapter::Base do
     allow(config).to receive(:silencer).and_return(silencer)
     allow(config).to receive(:adapter_options).and_return(adapter_options)
 
-    allow(Listen::Internals::ThreadPool).
-      to receive(:add) { |&block| block.call }
+    allow(Thread).to receive(:new) do |&block|
+      block.call
+      allow(thread).to receive(:name=)
+      thread
+    end
 
     # Stuff that happens in configure()
-    allow(Listen::Record).to receive(:new).with(dir1).and_return(record)
+    allow(Listen::Record).to receive(:new).with(dir1, silencer).and_return(record)
 
     allow(Listen::Change::Config).to receive(:new).with(queue, silencer).
       and_return(config)
