@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'listen/adapter/config'
 
 RSpec.describe Listen::Adapter::Config do
@@ -63,7 +65,7 @@ RSpec.describe Listen::Adapter::Config do
         end
 
         context 'when not resolved' do
-          let(:directories) { %w(symlinked_dir1 symlinked_dir2) }
+          let(:directories) { %w[symlinked_dir1 symlinked_dir2] }
           it 'returns array of resolved pathnames' do
             expect(subject.directories).to eq([real_path1, real_path2])
           end
@@ -83,7 +85,7 @@ RSpec.describe Listen::Adapter::Config do
     end
 
     context 'with no directories' do
-      let(:directories) {}
+      let(:directories) { }
       it 'returns the current path in array' do
         expect(subject.directories).to eq([real_current_path])
       end
