@@ -1,7 +1,8 @@
+# frozen_string_literal: true
+
 include Listen
 
 RSpec.describe Listener do
-
   let(:realdir1) { fake_path('/foo/dir1', children: []) }
   let(:realdir2) { fake_path('/foo/dir2', children: []) }
 
@@ -72,7 +73,7 @@ RSpec.describe Listener do
     allow(Pathname).to receive(:new).with('dir1').and_return(dir1)
     allow(Pathname).to receive(:new).with('dir2').and_return(dir2)
 
-    allow(Internals::ThreadPool).to receive(:add).and_return(processing_thread)
+    allow(Thread).to receive(:new).and_return(processing_thread)
     allow(processing_thread).to receive(:alive?).and_return(true)
     allow(processing_thread).to receive(:wakeup)
     allow(processing_thread).to receive(:join)
@@ -85,8 +86,12 @@ RSpec.describe Listener do
 
     context 'with a block' do
       let(:myblock) { instance_double(Proc) }
-      let(:block) { proc { myblock.call }  }
-      subject { described_class.new('dir1', &block) }
+      let(:block) { proc { myblock.call } }
+      subject do
+        described_class.new('dir1') do |*args|
+          myblock.call(*args)
+        end
+      end
 
       it 'passes the block to the event processor' do
         allow(Event::Config).to receive(:new) do |*_args, &some_block|
@@ -104,7 +109,7 @@ RSpec.describe Listener do
 
       it 'passes directories to backend' do
         allow(Backend).to receive(:new).
-          with(['dir1', 'dir2'], anything, anything, anything).
+          with(%w[dir1 dir2], anything, anything, anything).
           and_return(backend)
         subject
       end
@@ -118,16 +123,14 @@ RSpec.describe Listener do
     end
 
     it 'sets paused to false' do
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
+      allow(processor).to receive(:start)
       subject.start
       expect(subject).to_not be_paused
     end
 
     it 'starts adapter' do
       expect(backend).to receive(:start)
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
+      allow(processor).to receive(:start)
       subject.start
     end
   end
@@ -135,23 +138,38 @@ RSpec.describe Listener do
   describe '#stop' do
     before do
       allow(backend).to receive(:start)
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
-      subject.start
+      allow(processor).to receive(:start)
     end
 
-    it 'terminates' do
-      allow(backend).to receive(:stop)
-      allow(processor).to receive(:teardown)
-      subject.stop
+    context 'when fully started' do
+      before do
+        subject.start
+      end
+
+      it 'terminates' do
+        allow(backend).to receive(:stop)
+        allow(processor).to receive(:stop)
+        subject.stop
+      end
+    end
+
+    context 'when only initialized' do
+      before do
+        subject
+      end
+
+      it 'terminates' do
+        allow(backend).to receive(:stop)
+        allow(processor).to receive(:stop)
+        subject.stop
+      end
     end
   end
 
   describe '#pause' do
     before do
       allow(backend).to receive(:start)
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
+      allow(processor).to receive(:start)
       subject.start
     end
     it 'sets paused to true' do
@@ -164,8 +182,7 @@ RSpec.describe Listener do
   describe 'unpause with start' do
     before do
       allow(backend).to receive(:start)
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
+      allow(processor).to receive(:start)
       subject.start
       allow(processor).to receive(:pause)
       subject.pause
@@ -180,8 +197,7 @@ RSpec.describe Listener do
   describe '#paused?' do
     before do
       allow(backend).to receive(:start)
-      allow(processor).to receive(:setup)
-      allow(processor).to receive(:resume)
+      allow(processor).to receive(:start)
       subject.start
     end
 
@@ -200,8 +216,7 @@ RSpec.describe Listener do
     context 'when processing' do
       before do
         allow(backend).to receive(:start)
-        allow(processor).to receive(:setup)
-        allow(processor).to receive(:resume)
+        allow(processor).to receive(:start)
         subject.start
       end
       it { should be_processing }
@@ -214,8 +229,7 @@ RSpec.describe Listener do
     context 'when paused' do
       before do
         allow(backend).to receive(:start)
-        allow(processor).to receive(:setup)
-        allow(processor).to receive(:resume)
+        allow(processor).to receive(:start)
         subject.start
         allow(processor).to receive(:pause)
         subject.pause
@@ -304,17 +318,4 @@ RSpec.describe Listener do
       end
     end
   end
-
-  describe 'processing changes' do
-    before do
-      allow(backend).to receive(:start)
-    end
-  end
-
-  context 'when listener is stopped' do
-    before do
-      subject.stop
-      allow(silencer).to receive(:silenced?) { true }
-    end
-  end
 end
