@@ -1,6 +1,10 @@
+# frozen_string_literal: true
+
 RSpec.describe Listen::Record do
   let(:dir) { instance_double(Pathname, to_s: '/dir') }
-  let(:record) { Listen::Record.new(dir) }
+  let(:silencer_options) { { ignore!: [/\A\.ignored/] } }
+  let(:silencer) { Listen::Silencer.new(**silencer_options) }
+  let(:record) { Listen::Record.new(dir, silencer) }
 
   def dir_entries_for(hash)
     hash.each do |dir, entries|
@@ -21,7 +25,7 @@ RSpec.describe Listen::Record do
   end
 
   def lstat(path, stat = nil)
-    stat ||= instance_double(::File::Stat, mtime: 2.3, mode: 0755)
+    stat ||= instance_double(::File::Stat, mtime: 2.3, mode: 0755, size: 42)
     allow(::File).to receive(:lstat).with(path).and_return(stat)
     stat
   end
@@ -32,7 +36,7 @@ RSpec.describe Listen::Record do
   end
 
   def symlink(hash_or_dir)
-    if String === hash_or_dir
+    if hash_or_dir.is_a?(String)
       allow(::File).to receive(:realpath).with(hash_or_dir).
         and_return(hash_or_dir)
     else
@@ -106,7 +110,7 @@ RSpec.describe Listen::Record do
 
       watched = record_tree(record)
       expect(watched.keys).to eq ['path/subdir']
-      expect(watched['path/subdir'].keys).to eq %w(file.rb file2.rb)
+      expect(watched['path/subdir'].keys).to eq %w[file.rb file2.rb]
 
       subdir = watched['path/subdir']
       expect(subdir['file.rb']).to eq(mtime: 1.1)
@@ -206,6 +210,29 @@ RSpec.describe Listen::Record do
       end
     end
 
+    context 'when there is a file with the same name as a dir' do
+      subject { record.dir_entries('cypress') }
+
+      before do
+        record.update_file('cypress.json', mtime: 1.1)
+        record.update_file('cypress/README.md', mtime: 1.2)
+        record.update_file('a/b/cypress/d', mtime: 1.3)
+        record.update_file('a/b/c/cypress', mtime: 1.3)
+      end
+      it { should eq('README.md' => { mtime: 1.2 }) }
+    end
+
+    context 'when there is a file with a similar name to a dir' do
+      subject { record.dir_entries('app') }
+
+      before do
+        record.update_file('appspec.yml', mtime: 1.1)
+        record.update_file('app/README.md', mtime: 1.2)
+        record.update_file('spec/app/foo', mtime: 1.3)
+      end
+      it { should eq('README.md' => { mtime: 1.2 }) }
+    end
+
     context 'in subdir /path' do
       subject { record.dir_entries('path') }
 
@@ -217,6 +244,19 @@ RSpec.describe Listen::Record do
         before { record.update_file('path/file.rb', mtime: 1.1) }
         it { should eq('file.rb' => { mtime: 1.1 }) }
       end
+
+      context 'with empty path/subdir' do
+        before { record.add_dir('path/subdir') }
+        it { should be_empty }
+      end
+
+      context 'with path/subdir with file' do
+        before do
+          record.add_dir('path/subdir')
+          record.update_file('path/subdir/file.rb', mtime: 1.1)
+        end
+        it { should be_empty }
+      end
     end
   end
 
@@ -225,8 +265,8 @@ RSpec.describe Listen::Record do
 
     before do
       stubs = {
-        ::File => %w(lstat realpath),
-        ::Dir => %w(entries exist?)
+        ::File => %w[lstat realpath],
+        ::Dir => %w[entries exist?]
       }
 
       stubs.each do |klass, meths|
@@ -248,12 +288,12 @@ RSpec.describe Listen::Record do
       expect(record.file_data('path/file.rb')).to be_empty
     end
 
-    let(:foo_stat) { instance_double(::File::Stat, mtime: 1.0, mode: 0644) }
-    let(:bar_stat) { instance_double(::File::Stat, mtime: 2.3, mode: 0755) }
+    let(:foo_stat) { instance_double(::File::Stat, mtime: 1.0, mode: 0644, size: 42) }
+    let(:bar_stat) { instance_double(::File::Stat, mtime: 2.3, mode: 0755, size: 42) }
 
     context 'with no subdirs' do
       before do
-        real_directory('/dir' => %w(foo bar))
+        real_directory('/dir' => %w[foo bar])
         lstat(file('/dir/foo'), foo_stat)
         lstat(file('/dir/bar'), bar_stat)
         real_directory('/dir2' => [])
@@ -263,36 +303,38 @@ RSpec.describe Listen::Record do
         record.build
         expect(record_tree(record)).
           to eq(
-            'foo' => { mtime: 1.0, mode: 0644 },
-            'bar' => { mtime: 2.3, mode: 0755 })
+            'foo' => { mtime: 1.0, mode: 0644, size: 42 },
+            'bar' => { mtime: 2.3, mode: 0755, size: 42 })
       end
     end
 
     context 'with subdir containing files' do
       before do
-        real_directory('/dir' => %w(dir1 dir2))
-        real_directory('/dir/dir1' => %w(foo))
-        real_directory('/dir/dir1/foo' => %w(bar))
+        real_directory('/dir' => %w[dir1 dir2 .ignored])
+        real_directory('/dir/dir1' => %w[foo])
+        real_directory('/dir/dir1/foo' => %w[bar])
+        lstat(file('/dir/.ignored/FETCH_HEAD'))
         lstat(file('/dir/dir1/foo/bar'))
         real_directory('/dir/dir2' => [])
       end
 
-      it 'builds record'  do
+      it 'builds record, skipping silenced patterns' do
         record.build
         expect(record_tree(record)).
           to eq(
             'dir1' => {},
-            'dir1/foo' => { 'bar' => { mtime: 2.3, mode: 0755 } },
-            'dir2' => {},
-        )
+            'dir1/foo' => { 'bar' => { mtime: 2.3, mode: 0755, size: 42 } },
+            'dir2' => {}
+          )
       end
     end
 
     context 'with subdir containing dirs' do
       before do
-        real_directory('/dir' => %w(dir1 dir2))
-        real_directory('/dir/dir1' => %w(foo))
-        real_directory('/dir/dir1/foo' => %w(bar baz))
+        real_directory('/dir' => %w[dir1 dir2 .ignored])
+        real_directory('/dir/.ignored' => %w[ignored_file])
+        real_directory('/dir/dir1' => %w[foo])
+        real_directory('/dir/dir1/foo' => %w[bar baz])
         real_directory('/dir/dir1/foo/bar' => [])
         real_directory('/dir/dir1/foo/baz' => [])
         real_directory('/dir/dir2' => [])
@@ -300,7 +342,7 @@ RSpec.describe Listen::Record do
         allow(::File).to receive(:realpath) { |path| path }
       end
 
-      it 'builds record'  do
+      it 'builds record' do
         record.build
         expect(record_tree(record)).
           to eq(
@@ -308,24 +350,24 @@ RSpec.describe Listen::Record do
             'dir1/foo' => {},
             'dir1/foo/bar' => {},
             'dir1/foo/baz' => {},
-            'dir2' => {},
-        )
+            'dir2' => {}
+          )
       end
     end
 
     context 'with subdir containing symlink to parent' do
       subject { record.paths }
       before do
-        real_directory('/dir' => %w(dir1 dir2))
-        real_directory('/dir/dir1' => %w(foo))
-        dir_entries_for('/dir/dir1/foo' => %w(dir1))
+        real_directory('/dir' => %w[dir1 dir2])
+        real_directory('/dir/dir1' => %w[foo])
+        dir_entries_for('/dir/dir1/foo' => %w[dir1])
         symlink('/dir/dir1/foo' => '/dir/dir1')
 
         real_directory('/dir/dir2' => [])
       end
 
       it 'shows a warning' do
-        expect(STDERR).to receive(:puts).
+        expect_any_instance_of(Listen::Record::SymlinkDetector).to receive(:warn).
           with(/directory is already being watched/)
 
         record.build
@@ -338,14 +380,14 @@ RSpec.describe Listen::Record do
       subject { record.paths }
 
       before do
-        real_directory('/dir' => %w(dir1))
-        real_directory('/dir/dir1' => %w(foo))
+        real_directory('/dir' => %w[dir1])
+        real_directory('/dir/dir1' => %w[foo])
 
         symlink('/dir/dir1/foo' => '/dir/dir2')
-        dir_entries_for('/dir/dir1/foo' => %w(bar))
+        dir_entries_for('/dir/dir1/foo' => %w[bar])
         lstat(realpath(file('/dir/dir1/foo/bar')))
 
-        real_directory('/dir/dir2' => %w(bar))
+        real_directory('/dir/dir2' => %w[bar])
         lstat(file('/dir/dir2/bar'))
       end
 
@@ -358,8 +400,8 @@ RSpec.describe Listen::Record do
     context 'with subdir containing symlinked file' do
       subject { record.paths }
       before do
-        real_directory('/dir' => %w(dir1 dir2))
-        real_directory('/dir/dir1' => %w(foo))
+        real_directory('/dir' => %w[dir1 dir2])
+        real_directory('/dir/dir1' => %w[foo])
         lstat(file('/dir/dir1/foo'))
         real_directory('/dir/dir2' => [])
       end
